## 美股交易日历

接口：us_tradecal

描述：获取美股交易日历信息

限量：单次最大6000，可根据日期阶段获取

输入参数

| 名称 | 类型 | 必选 | 描述 | 示例 |
| --- | --- | --- | --- | --- |
| start_date | str | N | 开始日期 | 20200101 |
| end_date | str | N | 结束日期 | 20200701 |
| is_open | str | N | 是否交易 | 0：休市 、1：交易 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| cal_date | str | Y | 日历日期 |
| is_open | int | Y | 是否交易 '0'休市 '1'交易 |
| pretrade_date | str | Y | 上一个交易日 |

接口示例

```python
pro = ts.pro_api()

df = pro.us_tradecal(start_date='20200101', end_date='20200701')
```

数据示例

```python
cal_date  is_open pretrade_date
0    20200701        1      20200630
```